# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto',
  package='github.com.metaprov.modelaapi.services.dataapp.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/dataapp/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto\x12\x31github.com.metaprov.modelaapi.services.dataapp.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xc9\x01\n\x13ListDataAppsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\x14ListDataAppsResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataAppList\"\x17\n\x15\x43reateDataAppResponse\"h\n\x14\x43reateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"h\n\x14UpdateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x17\n\x15UpdateDataAppResponse\"4\n\x11GetDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x12GetDataAppResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteDataAppResponse\"6\n\x13PauseDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14PauseDataAppResponse\"7\n\x14ResumeDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15ResumeDataAppResponse\"e\n\x11RunDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x14\n\x12RunDataAppResponse2\xfd\n\n\x0e\x44\x61taAppService\x12\xb8\x01\n\x0cListDataApps\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/webeequests\x12\xbe\x01\n\rCreateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webeequests:\x01*\x12\xb9\x01\n\nGetDataApp\x12\x44.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/webeequests/{name}\x12\xd9\x01\n\rUpdateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/webeequests/{webeequest.metadata.name}:\x01*\x12\xc2\x01\n\rDeleteDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/webeequests/{name}\x12\xc5\x01\n\x0cPauseDataApp\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/v1/webeequests/{name}:pause\x12\xc9\x01\n\rResumeDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/v1/webeequests/{name}:resumeB3Z1github.com/metaprov/modelaapi/services/dataapp/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTDATAAPPSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=425,
)

_LISTDATAAPPSREQUEST = _descriptor.Descriptor(
  name='ListDataAppsRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATAAPPSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=425,
)


_LISTDATAAPPSRESPONSE = _descriptor.Descriptor(
  name='ListDataAppsResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=536,
)


_CREATEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='CreateDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=561,
)


_CREATEDATAAPPREQUEST = _descriptor.Descriptor(
  name='CreateDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=667,
)


_UPDATEDATAAPPREQUEST = _descriptor.Descriptor(
  name='UpdateDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=773,
)


_UPDATEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='UpdateDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=798,
)


_GETDATAAPPREQUEST = _descriptor.Descriptor(
  name='GetDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=852,
)


_GETDATAAPPRESPONSE = _descriptor.Descriptor(
  name='GetDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=970,
)


_DELETEDATAAPPREQUEST = _descriptor.Descriptor(
  name='DeleteDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1027,
)


_DELETEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='DeleteDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1029,
  serialized_end=1052,
)


_PAUSEDATAAPPREQUEST = _descriptor.Descriptor(
  name='PauseDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1108,
)


_PAUSEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='PauseDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1132,
)


_RESUMEDATAAPPREQUEST = _descriptor.Descriptor(
  name='ResumeDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1189,
)


_RESUMEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='ResumeDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1191,
  serialized_end=1214,
)


_RUNDATAAPPREQUEST = _descriptor.Descriptor(
  name='RunDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1216,
  serialized_end=1317,
)


_RUNDATAAPPRESPONSE = _descriptor.Descriptor(
  name='RunDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1339,
)

_LISTDATAAPPSREQUEST_LABELSENTRY.containing_type = _LISTDATAAPPSREQUEST
_LISTDATAAPPSREQUEST.fields_by_name['labels'].message_type = _LISTDATAAPPSREQUEST_LABELSENTRY
_LISTDATAAPPSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPPLIST
_CREATEDATAAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
_UPDATEDATAAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
_GETDATAAPPRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
_RUNDATAAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
DESCRIPTOR.message_types_by_name['ListDataAppsRequest'] = _LISTDATAAPPSREQUEST
DESCRIPTOR.message_types_by_name['ListDataAppsResponse'] = _LISTDATAAPPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataAppResponse'] = _CREATEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataAppRequest'] = _CREATEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataAppRequest'] = _UPDATEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataAppResponse'] = _UPDATEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['GetDataAppRequest'] = _GETDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['GetDataAppResponse'] = _GETDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDataAppRequest'] = _DELETEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataAppResponse'] = _DELETEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['PauseDataAppRequest'] = _PAUSEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['PauseDataAppResponse'] = _PAUSEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['ResumeDataAppRequest'] = _RESUMEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['ResumeDataAppResponse'] = _RESUMEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['RunDataAppRequest'] = _RUNDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['RunDataAppResponse'] = _RUNDATAAPPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDataAppsRequest = _reflection.GeneratedProtocolMessageType('ListDataAppsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAAPPSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAAPPSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest)
  })
_sym_db.RegisterMessage(ListDataAppsRequest)
_sym_db.RegisterMessage(ListDataAppsRequest.LabelsEntry)

ListDataAppsResponse = _reflection.GeneratedProtocolMessageType('ListDataAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse)
  })
_sym_db.RegisterMessage(ListDataAppsResponse)

CreateDataAppResponse = _reflection.GeneratedProtocolMessageType('CreateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse)
  })
_sym_db.RegisterMessage(CreateDataAppResponse)

CreateDataAppRequest = _reflection.GeneratedProtocolMessageType('CreateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest)
  })
_sym_db.RegisterMessage(CreateDataAppRequest)

UpdateDataAppRequest = _reflection.GeneratedProtocolMessageType('UpdateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest)
  })
_sym_db.RegisterMessage(UpdateDataAppRequest)

UpdateDataAppResponse = _reflection.GeneratedProtocolMessageType('UpdateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse)
  })
_sym_db.RegisterMessage(UpdateDataAppResponse)

GetDataAppRequest = _reflection.GeneratedProtocolMessageType('GetDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest)
  })
_sym_db.RegisterMessage(GetDataAppRequest)

GetDataAppResponse = _reflection.GeneratedProtocolMessageType('GetDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse)
  })
_sym_db.RegisterMessage(GetDataAppResponse)

DeleteDataAppRequest = _reflection.GeneratedProtocolMessageType('DeleteDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest)
  })
_sym_db.RegisterMessage(DeleteDataAppRequest)

DeleteDataAppResponse = _reflection.GeneratedProtocolMessageType('DeleteDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse)
  })
_sym_db.RegisterMessage(DeleteDataAppResponse)

PauseDataAppRequest = _reflection.GeneratedProtocolMessageType('PauseDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest)
  })
_sym_db.RegisterMessage(PauseDataAppRequest)

PauseDataAppResponse = _reflection.GeneratedProtocolMessageType('PauseDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse)
  })
_sym_db.RegisterMessage(PauseDataAppResponse)

ResumeDataAppRequest = _reflection.GeneratedProtocolMessageType('ResumeDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest)
  })
_sym_db.RegisterMessage(ResumeDataAppRequest)

ResumeDataAppResponse = _reflection.GeneratedProtocolMessageType('ResumeDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse)
  })
_sym_db.RegisterMessage(ResumeDataAppResponse)

RunDataAppRequest = _reflection.GeneratedProtocolMessageType('RunDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest)
  })
_sym_db.RegisterMessage(RunDataAppRequest)

RunDataAppResponse = _reflection.GeneratedProtocolMessageType('RunDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse)
  })
_sym_db.RegisterMessage(RunDataAppResponse)


DESCRIPTOR._options = None
_LISTDATAAPPSREQUEST_LABELSENTRY._options = None

_DATAAPPSERVICE = _descriptor.ServiceDescriptor(
  name='DataAppService',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1342,
  serialized_end=2747,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataApps',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.ListDataApps',
    index=0,
    containing_service=None,
    input_type=_LISTDATAAPPSREQUEST,
    output_type=_LISTDATAAPPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/webeequests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.CreateDataApp',
    index=1,
    containing_service=None,
    input_type=_CREATEDATAAPPREQUEST,
    output_type=_CREATEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/webeequests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.GetDataApp',
    index=2,
    containing_service=None,
    input_type=_GETDATAAPPREQUEST,
    output_type=_GETDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.UpdateDataApp',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATAAPPREQUEST,
    output_type=_UPDATEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/webeequests/{webeequest.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.DeleteDataApp',
    index=4,
    containing_service=None,
    input_type=_DELETEDATAAPPREQUEST,
    output_type=_DELETEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.PauseDataApp',
    index=5,
    containing_service=None,
    input_type=_PAUSEDATAAPPREQUEST,
    output_type=_PAUSEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\034/v1/webeequests/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.ResumeDataApp',
    index=6,
    containing_service=None,
    input_type=_RESUMEDATAAPPREQUEST,
    output_type=_RESUMEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\"\035/v1/webeequests/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAAPPSERVICE)

DESCRIPTOR.services_by_name['DataAppService'] = _DATAAPPSERVICE

# @@protoc_insertion_point(module_scope)
